# Careers at swarms

We are a team of engineers, developers, and visionaries on a mission to build the future of AI by orchestrating multi-agent collaboration. We move fast, think ambitiously, and deliver with urgency. Join us if you want to be part of building the next generation of multi-agent systems, redefining how businesses automate operations and leverage AI.

**We offer none of the following benefits Yet:**

- No medical, dental, or vision insurance

- No paid time off

- No life or AD&D insurance

- No short-term or long-term disability insurance

- No 401(k) plan

**Working hours:** 9 AM to 10 PM, every day, 7 days a week. This is not for people who seek work-life balance.

---

### Hiring Process: How to Join swarms

We have a simple 3-step hiring process:

**NOTE** We do not consider applicants who have not previously submitted a PR, to be considered a PR containing a new feature of a bug fixed must be submitted.

1. **Submit a pull request (PR)**: Start by submitting an approved PR to the [swarms GitHub repository](https://github.com/kyegomez/swarms) or the appropriate repository .
2. **Code review**: Our technical team will review your PR. If it meets our standards, you will be invited for a quick interview.
3. **Final interview**: Discuss your contributions and approach with our team. If you pass, you're in!

There are no recruiters. All evaluations are done by our technical team.

---

# Location

- **Palo Alto** CA Our Palo Alto office houses the majority of our core research teams including our prompting, agent design, and model training

- **Miami** Our miami office holds prompt engineering, agent design, and more.

### Open Roles at swarms

**Infrastructure Engineer**

- Build and maintain the systems that run our AI multi-agent infrastructure.

- Expertise in Skypilot, AWS, Terraform.

- Ensure seamless, high-availability environments for agent operations.

**Agent Engineer**

- Design, develop, and orchestrate complex swarms of AI agents.

- Extensive experience with Python, multi-agent systems, and neural networks.

- Ability to create dynamic and efficient agent architectures from scratch.

**Prompt Engineer**

- Craft highly optimized prompts that drive our LLM-based agents.

- Specialize in instruction-based prompts, multi-shot examples, and production-grade deployment.

- Collaborate with agents to deliver state-of-the-art solutions.

**Front-End Engineer**

- Build sleek, intuitive interfaces for interacting with swarms of agents.

- Proficiency in Next.js, FastAPI, and modern front-end technologies.

- Design with the user experience in mind, integrating complex AI features into simple workflows.
